#ifndef _CEGOEXCEPTION_H_INCLUDED_
#define _CEGOEXCEPTION_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoException.h
// ---------------
// Cego exception type definitions
//                                                         
// Design and Implementation by Bjoern Lemke               
//     
// (C)opyright 2000-2025 Bjoern Lemke
//
// INTERFACE MODULE
//
// Class: CegoException
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

enum CegoException {
    NONE_EXCEP,
    COREOP_EXCEP,
    OTHER_EXCEP,
    ANY_EXCEP,
    RETURN_EXCEP,
    ABORT_EXCEP
};
#endif




